@@ -20,6 +20,7 @@ def setup(app):
 
 extensions = ['breathe']
 breathe_projects = { 'xtensor': '../xml' }
+breathe_default_project = "xtensor"
 templates_path = ['_templates']
 html_static_path = ['_static']
 source_suffix = '.rst'
@@ -40,7 +41,7 @@ html_js_files = [
     'goatcounter.js'
 ]
 
-# Automatically link to numpy doc
+# Automatically link to NumPy doc
 extensions += ['sphinx.ext.intersphinx']
 intersphinx_mapping = {
     "numpy": ("https://numpy.org/doc/stable/", None),
