@@ -1,21 +1,22 @@
 /***************************************************************************
-* Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
-* Copyright (c) QuantStack                                                 *
-*                                                                          *
-* Distributed under the terms of the BSD 3-Clause License.                 *
-*                                                                          *
-* The full license is in the file LICENSE, distributed with this software. *
-****************************************************************************/
-
-#include "test_common_macros.hpp"
-#include "xtensor/xnorm.hpp"
-#include "xtensor/xarray.hpp"
-#include "xtensor/xbuilder.hpp"
-#include "xtensor/xview.hpp"
-#include "xtensor/xnoalias.hpp"
+ * Copyright (c) Johan Mabille, Sylvain Corlay and Wolf Vollprecht          *
+ * Copyright (c) QuantStack                                                 *
+ *                                                                          *
+ * Distributed under the terms of the BSD 3-Clause License.                 *
+ *                                                                          *
+ * The full license is in the file LICENSE, distributed with this software. *
+ ****************************************************************************/
 
 #include <limits>
 
+#include "xtensor/xarray.hpp"
+#include "xtensor/xbuilder.hpp"
+#include "xtensor/xnoalias.hpp"
+#include "xtensor/xnorm.hpp"
+#include "xtensor/xview.hpp"
+
+#include "test_common_macros.hpp"
+
 namespace xt
 {
     TEST(xnorm, norm_traits)
@@ -168,8 +169,7 @@ namespace xt
 
     TEST(xnorm, matrix)
     {
-        xarray<double> a = {{ -1.0, 2.0},
-                            { -3.0, 4.0}};
+        xarray<double> a = {{-1.0, 2.0}, {-3.0, 4.0}};
 
         EXPECT_EQ(norm_l0(a)(), 4u);
         EXPECT_EQ(norm_l1(a)(), 10.0);
